import React, { useContext, useEffect } from 'react';
import { View, FlatList } from 'react-native';
import { Accordion, Text, ListItem, Body, CheckBox } from 'native-base';
import Icon from 'react-native-vector-icons/AntDesign';
import { styles } from './style';
import TreeDropdownContext from './TreeDropdownContext';
// type selectedChildProp = {
//   [key: string]: string[];
// };
// export type selectedListProps = {
//   key: selectedParentProp;
//   [keyChild: string]: string[];
// };
export const TreeListItem = props => {
  const {
    data,
    childName,
    parentName,
    value,
    onChange
  } = props;
  const context = useContext(TreeDropdownContext).current;
  const {
    selectedList,
    setSelectedList,
    selectChild
  } = context;
  useEffect(() => {
    if (value) {
      setSelectedList(value);
    }
  }, [value]);
  useEffect(() => {
    onChange(selectedList);
  }, [selectedList]);

  const checkSelected = (parentId, childId) => {
    if (selectedList.length === 0) {
      return false;
    }

    const x = selectedList.find(val => val[parentName] === parentId);

    if (!x) {
      return false;
    }

    const ind = x[childName].findIndex(itm => itm === childId);
    return ind !== -1;
  };

  const _renderHeader = (item, expanded) => {
    return /*#__PURE__*/React.createElement(View, {
      style: {
        flexDirection: 'row',
        padding: 10,
        justifyContent: 'space-between',
        alignItems: 'center',
        backgroundColor: 'white'
      }
    }, /*#__PURE__*/React.createElement(Text, {
      style: {
        fontWeight: '600',
        color: '#666666'
      }
    }, ' ', item.parent.label), expanded ? /*#__PURE__*/React.createElement(Icon, {
      style: {
        fontSize: 18
      },
      name: "up"
    }) : /*#__PURE__*/React.createElement(Icon, {
      style: {
        fontSize: 18
      },
      name: "down"
    }));
  };

  const _renderContent = val => {
    return /*#__PURE__*/React.createElement(FlatList, {
      maxToRenderPerBatch: 10,
      data: val.children,
      renderItem: ({
        item,
        index
      }) => /*#__PURE__*/React.createElement(ListItem, {
        key: index
      }, /*#__PURE__*/React.createElement(Body, null, /*#__PURE__*/React.createElement(Text, {
        style: styles.childText
      }, item.label)), /*#__PURE__*/React.createElement(CheckBox, {
        color: '#979797',
        style: styles.checkbox,
        onPress: () => selectChild(item.value, val.parent.value),
        checked: checkSelected(val.parent.value, item.value)
      })),
      keyExtractor: item => item.value,
      scrollEnabled: true
    });
  };

  return /*#__PURE__*/React.createElement(View, null, /*#__PURE__*/React.createElement(Accordion, {
    dataArray: data // animation={true}
    // expanded={true}
    ,
    renderHeader: _renderHeader,
    renderContent: _renderContent
  }));
};
//# sourceMappingURL=TreeListItem.js.map