import React, { FC, useContext, useEffect } from 'react';
import { View, FlatList } from 'react-native';
import { Accordion, Text, ListItem, Body, CheckBox } from 'native-base';
import Icon from 'react-native-vector-icons/AntDesign';
import { TreeItemProp } from './TreeDropdown';
import { ItemProp } from '../MultiSelect/MultiSelectDropDown';
import { styles } from './style';
import TreeDropdownContext from './TreeDropdownContext';

export type TreeListItemProps = {
  data: TreeItemProp[];
  value?: any[];
  parentName: string;
  childName: string;
  onChange: (val: any) => void;
};

// type selectedChildProp = {
//   [key: string]: string[];
// };
// export type selectedListProps = {
//   key: selectedParentProp;
//   [keyChild: string]: string[];
// };
export const TreeListItem: FC<TreeListItemProps> = (
  props: TreeListItemProps
) => {
  const { data, childName, parentName, value, onChange } = props;
  const context = useContext(TreeDropdownContext).current!;
  const { selectedList, setSelectedList, selectChild } = context;

  useEffect(() => {
    if (value) {
      setSelectedList(value);
    }
  }, [value]);
  useEffect(() => {
    onChange(selectedList);
  }, [selectedList]);

  const checkSelected = (parentId: string, childId: string): boolean => {
    if (selectedList.length === 0) {
      return false;
    }
    const x = selectedList.find(
      (val: { [x: string]: string | undefined }) => val[parentName] === parentId
    );
    if (!x) {
      return false;
    }
    const ind = x[childName].findIndex((itm: string) => itm === childId);
    return ind !== -1;
  };
  const _renderHeader = (item: TreeItemProp, expanded: boolean) => {
    return (
      <View
        style={{
          flexDirection: 'row',
          padding: 10,
          justifyContent: 'space-between',
          alignItems: 'center',
          backgroundColor: 'white',
        }}
      >
        <Text style={{ fontWeight: '600', color: '#666666' }}>
          {' '}
          {item.parent.label}
        </Text>
        {expanded ? (
          <Icon style={{ fontSize: 18 }} name="up" />
        ) : (
          <Icon style={{ fontSize: 18 }} name="down" />
        )}
      </View>
    );
  };
  const _renderContent = (val: TreeItemProp): React.ReactElement<any> => {
    return (
      <FlatList
        maxToRenderPerBatch={10}
        data={val.children}
        renderItem={({ item, index }) => (
          <ListItem key={index}>
            <Body>
              <Text style={styles.childText}>{item.label}</Text>
            </Body>
            <CheckBox
              color={'#979797'}
              style={styles.checkbox}
              onPress={() => selectChild(item.value, val.parent.value)}
              checked={checkSelected(val.parent.value, item.value)}
            />
          </ListItem>
        )}
        keyExtractor={(item: ItemProp) => item.value}
        scrollEnabled
      />
    );
  };
  return (
    <View>
      <Accordion
        dataArray={data}
        // animation={true}
        // expanded={true}
        renderHeader={_renderHeader}
        renderContent={_renderContent}
      />
    </View>
  );
};
