import React, { FC, useMemo, useState } from 'react';
import { styles } from './styles';
import { Item, Label, NativeBase, RnViewStyleProp, View } from 'native-base';
import { TouchableOpacity, Image } from 'react-native';
import { default as ImagePickerX } from 'react-native-image-picker';
import { ImagePickerOptions } from 'react-native-image-picker/src/internal/types';

// type imageDataProps = {
//   src: string;
//   dataBase64: string;
// };
export type ImageUploaderProps = {
  type?: 'avatar' | 'primary' | 'avatar-edit';
  ImagePickerStyle?: any;
  label?: string;
  style?: RnViewStyleProp;
  labelProps?: NativeBase.Label;
  validationInfo?: string[];
  onChange: (val: string) => void;
  value?: string;
  pickerOptions?: ImagePickerOptions;
  alignPicker?: 'center' | 'flex-start' | 'flex-end';
};
export const ImagePicker: FC<ImageUploaderProps> = (
  props: ImageUploaderProps
) => {
  const {
    type,
    label,
    labelProps,
    style,
    ImagePickerStyle,
    onChange,
    value,
    pickerOptions,
    alignPicker,
  } = props;
  const [image, setImage] = useState<{ uri: string }>();
  const options: ImagePickerOptions = {
    title: 'Select Picture',
    mediaType: 'photo',
    allowsEditing: true,
    quality: 0.7,
    // storageOptions: {
    //   skipBackup: true,
    //   path: 'images',
    // },
    maxWidth: type === 'avatar' || type === 'avatar-edit' ? 300 : 1000,
    maxHeight: type === 'avatar' || type === 'avatar-edit' ? 300 : 700,
  };
  // useEffect(() => {
  //  if(type === 'avatar'){
  //    setImageProps({
  //
  //    })
  //  }
  // })
  const onPress = () => {
    ImagePickerX.showImagePicker(
      pickerOptions ? { ...options, ...pickerOptions } : options,
      (response) => {
        if (response.didCancel) {
          console.log('User cancelled image picker');
        } else if (response.error) {
          console.log('ImagePicker Error: ', response.error);
        } else if (response.customButton) {
          console.log('User tapped custom button: ', response.customButton);
        } else {
          setImage({ uri: response.uri });
          onChange(`data:image/png;base64,${response.data}`);
        }
      }
    );
  };
  const imageSrc = useMemo(() => {
    if (value && (value === image?.uri || image?.uri === undefined)) {
      return { uri: value };
    }
    return image;
  }, [value, image]);
  const renderElement = (pickerStyleX?: any) => {
    return (
      <Item
        stackedLabel={label !== undefined}
        style={[
          style !== undefined
            ? { ...styles.itemStyle, ...(style as object) }
            : styles.itemStyle,
          { alignItems: alignPicker ?? 'center' },
        ]}
      >
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...styles.textDefault, ...(labelProps.style as object) }
                : styles.textDefault
            }
          >
            {label}
          </Label>
        )}
        <TouchableOpacity onPress={onPress}>
          {!imageSrc ? (
            <View
              style={
                ImagePickerStyle
                  ? { ...ImagePickerStyle, ...pickerStyleX }
                  : pickerStyleX
              }
            >
              <Image
                style={{ height: 50, width: 50 }}
                source={require('./ImageIcon.png')}
              />
            </View>
          ) : (
            <Image
              source={imageSrc}
              resizeMode={
                type === 'avatar' || type === 'avatar-edit'
                  ? undefined
                  : 'cover'
              }
              style={
                ImagePickerStyle
                  ? { ...ImagePickerStyle, ...pickerStyleX }
                  : pickerStyleX
              }
            />
          )}
          {type === 'avatar-edit' ? (
            <View style={styles.editIcon}>
              <Image
                style={styles.editIcon1}
                source={require('./pencilIcon1.png')}
              />
            </View>
          ) : null}
        </TouchableOpacity>
      </Item>
    );
  };
  if (type === 'avatar' || type === 'avatar-edit') {
    return renderElement(styles.avatar);
  }
  return renderElement(styles.defaultImage);
};
