import React, { FC } from 'react';
import {
  View,
  Spinner as SpinnerX,
  NativeBase,
  RnViewStyleProp,
} from 'native-base';
import { Modal, TouchableOpacity } from 'react-native';
import { colors } from '../../Configurations/ThemeConfig';
export type SpinnerProps = NativeBase.Spinner & {
  type?: 'full' | 'spinner-only';
  spaceColor?: string;
  themeColor?: string;
  styles?: RnViewStyleProp;
  background?: string;
};
export const Spinner: FC<SpinnerProps> = (props: SpinnerProps) => {
  const { themeColor, spaceColor, styles, type, background } = props;
  const propsX = { ...props };
  delete propsX.type;
  delete propsX.spaceColor;
  delete propsX.themeColor;
  delete propsX.styles;
  switch (type) {
    case 'full':
    default:
      return (
        <Modal transparent>
          <TouchableOpacity
            style={{
              alignContent: 'center',
              justifyContent: 'center',
              // backgroundColor: 'transparent',
              backgroundColor: background ?? 'rgba(0, 0, 0, 0.4)',
              flex: 1,
              height: '100%',
              width: '100%',
            }}
          >
            <View
              style={[
                {
                  backgroundColor: spaceColor ?? colors.white,
                  width: 90,
                  height: 90,
                  borderRadius: 12,
                  justifyContent: 'center',
                  alignItems: 'center',
                  alignSelf: 'center',
                  zIndex: 10,
                },
                styles,
              ]}
            >
              <SpinnerX
                {...propsX}
                style={{ paddingTop: 0 }}
                color={themeColor}
                size={'large'}
              />
            </View>
          </TouchableOpacity>
        </Modal>
      );
    case 'spinner-only':
      return (
        <View
          style={[
            {
              backgroundColor: spaceColor ?? 'white',
              width: 90,
              height: 90,
              borderRadius: 12,
              justifyContent: 'center',
              alignItems: 'center',
              alignSelf: 'center',
              zIndex: 10,
            },
            styles,
          ]}
        >
          <SpinnerX
            {...propsX}
            style={{ paddingTop: 0 }}
            color={themeColor}
            size={'large'}
          />
        </View>
      );
  }
};
